# Frequency filtering using a high-pass (HP) filter
# c: ideal (sharp edge) or Butterworth (smoothened edge) filter

clear all, close all, clc
im = imread('Images/Engine.tif'); # try also images Lincoln, Blobs!

[x,y] = meshgrid(-128:127, -128:127); # construct the HP filter
z = sqrt(x.^2 + y.^2);
##c = (z > 20); # ideal filter
c = 1 - (1./(1 + (z./20).^2)); # Butterworth filter

# HP frequency filtering
im_f = fftshift(fft2(im));
im_fh = im_f.*c; # multiplication in the frequency domain
im_fhi = ifft2(im_fh);

subplot(2, 3, 1), imshow(im), title('Original image')
subplot(2, 3, 2), imshow(c), title('HP filter')
subplot(2, 3, 3), imshow(log(1 + abs(im_f)), []), title('FT image')
subplot(2, 3, 4), imshow(log(1 + abs(im_fh)), []), title('HP filtering on FT image')
subplot(2, 3, 5), imshow(abs(im_fhi), []), title('HP filtered image')
