# Frequency filtering using a low-pass (LP) filter
# c: ideal (sharp edge) or Butterworth (smoothened edge) filter

clear all, close all, clc
pkg load image
im = imread('Images/Engine.tif'); # try also images Lincoln, Blobs!

[x,y] = meshgrid(-128:127, -128:127); # construct the LP filter
z = sqrt(x.^2 + y.^2);
##c = (z < 30); # ideal filter
c = 1 - (1./(1 + (z./15).^2)); c = imcomplement(c); # Butterworth filter

# LP frequency filtering
im_f = fftshift(fft2(im));
im_fh = im_f.*c; # multiplication in the frequency domain
im_fhi = ifft2(im_fh);

subplot(2, 3, 1), imshow(im), title('Original image')
subplot(2, 3, 2), imshow(c), title('LP filter')
subplot(2, 3, 3), imshow(log(1 + abs(im_f)), []), title('FT image')
subplot(2, 3, 4), imshow(log(1 + abs(im_fh)), []), title('LP filtering on FT image')
subplot(2, 3, 5), imshow(abs(im_fhi), []), title('LP filtered image')
